from setuptools import setup

setup(
    name='wscraping_helper',
    version='1.0.0',
    description='WebScraping helper module',
    author='Komáromi János',
    author_email='komaromijano2002@gmail.com',
    packages=['wscraping_helper'],
    install_requires=[
        "requests",
    ]
)